define(['exports'], (function (exports) { 'use strict';

	const lib1 = 'lib1';

	const lib1b = 'lib1b';

	exports.lib1 = lib1;
	exports.lib1b = lib1b;

}));
